@@ -2,8 +2,6 @@ import asyncio
 import functools
 import io
 import logging
-import os
-import shutil
 import sys
 import warnings
 from importlib import import_module
@@ -23,7 +21,6 @@ import apolo_cli
 
 from . import file_logging
 from .alias import find_alias
-from .asyncio_utils import setup_child_watcher
 from .click_types import setup_shell_completion
 from .const import (
     EX_DATAERR,
@@ -58,7 +55,6 @@ def setup_stdout(errors: str) -> None:
 
 
 setup_stdout(errors="replace")
-setup_child_watcher()
 
 
 log = logging.getLogger(__name__)
@@ -135,15 +131,12 @@ class MainGroup(Group):
                 raise click.UsageError(f"{option} requires --trace")
             hide_token_bool = kwargs["hide_token"]
 
-        # The following code is compatibility layer with old images
-        # New client doesn't make use of NEURO_STEAL_CONFIG, but
-        # it is better to remove it from storage
-        # TODO: remove this and upload_and_map_config function
-        if "NEURO_STEAL_CONFIG" in os.environ:
-            path = Path(os.environ["NEURO_STEAL_CONFIG"])
-            if path.exists():
-                shutil.rmtree(path)
-        # End of compatibility layer
+        config_path = kwargs["config_path"]
+        if config_path == apolo_sdk.DEFAULT_CONFIG_PATH:
+            # TODO: remove this fallback eventually
+            config_path = kwargs["neuromation_config"]
+            if config_path == apolo_sdk.DEFAULT_CONFIG_PATH:
+                config_path = None
 
         root = Root(
             verbosity=verbosity,
@@ -151,7 +144,7 @@ class MainGroup(Group):
             tty=tty,
             disable_pypi_version_check=kwargs["disable_pypi_version_check"],
             network_timeout=kwargs["network_timeout"],
-            config_path=Path(kwargs["neuromation_config"]),
+            config_path=Path(config_path) if config_path is not None else None,
             trace=kwargs["trace"],
             force_trace_all=kwargs["x_trace_all"],
             trace_hide_token=hide_token_bool,
@@ -312,6 +305,8 @@ CMD_MAP = {
     "secret": "apolo_cli.secrets:secret",
     "disk": "apolo_cli.disks:disk",
     "service-account": "apolo_cli.service_accounts:service_account",
+    "app": "apolo_cli.apps:app",
+    "app-template": "apolo_cli.app_template:app_template",
     # shortcuts
     "run": "apolo_cli.job:run",
     "ps": "apolo_cli.job:ls",
@@ -383,6 +378,15 @@ def print_options(
     default=0,
     help="Give less output. Option is additive, and can be used up to 2 times.",
 )
+@option(
+    "--config-path",
+    type=click.Path(dir_okay=True, file_okay=False),
+    required=False,
+    help="Path to config directory.",
+    default=apolo_sdk.DEFAULT_CONFIG_PATH,
+    metavar="PATH",
+    envvar=apolo_sdk.CONFIG_ENV_NAME,
+)
 @option(
     "--neuromation-config",
     type=click.Path(dir_okay=True, file_okay=False),
@@ -469,6 +473,7 @@ def cli(
     ctx: click.Context,
     verbose: int,
     quiet: bool,
+    config_path: str,
     neuromation_config: str,
     show_traceback: bool,
     color: str,
