@@ -6,10 +6,6 @@ from dateutil.parser import isoparse
 from rich.console import RenderableType
 
 from apolo_sdk import (
-    _AWSStorageOptions,
-    _AzureReplicationType,
-    _AzureStorageOptions,
-    _AzureStorageTier,
     _Balance,
     _CloudProviderOptions,
     _CloudProviderType,
@@ -19,16 +15,15 @@ from apolo_sdk import (
     _ClusterUserRoleType,
     _ClusterUserWithInfo,
     _ConfigCluster,
-    _EFSPerformanceMode,
-    _EFSThroughputMode,
     _GoogleCloudProvider,
     _GoogleFilestoreTier,
     _GoogleStorage,
-    _GoogleStorageOptions,
     _NodePool,
     _NodePoolOptions,
     _OnPremCloudProvider,
     _OrgCluster,
+    _OrgUserRoleType,
+    _OrgUserWithInfo,
     _Quota,
     _StorageInstance,
     _UserInfo,
@@ -40,6 +35,7 @@ from apolo_cli.formatters.admin import (
     ClusterUserFormatter,
     ClusterUserWithInfoFormatter,
     OrgClusterFormatter,
+    OrgUserFormatter,
 )
 
 RichCmp = Callable[[RenderableType], None]
@@ -149,12 +145,17 @@ class TestClustersFormatter:
             max_size=2,
             idle_size=1 if has_idle else 0,
             machine_type="n1-highmem-8",
+            cpu=8.0,
             available_cpu=7.0,
+            memory=51200 * 2**20,
             available_memory=46080 * 2**20,
             disk_size=150 * 2**30,
+            available_disk_size=100 * 2**30,
             disk_type=disk_type,
-            gpu=1 if is_gpu else 0,
-            gpu_model="nvidia-tesla-k80" if is_gpu else None,
+            nvidia_gpu=1 if is_gpu else 0,
+            nvidia_gpu_model="nvidia-tesla-k80" if is_gpu else None,
+            amd_gpu=1 if is_gpu else 0,
+            amd_gpu_model="instinct-mi25" if is_gpu else None,
             is_preemptible=is_preemptible,
         )
 
@@ -220,12 +221,11 @@ class TestClustersFormatter:
                         credentials={},
                         node_pools=[],
                         storage=_GoogleStorage(
-                            id="standard",
                             description="Filestore",
                             tier=_GoogleFilestoreTier.STANDARD,
                             instances=[
-                                _StorageInstance(size=2**30),
-                                _StorageInstance(name="org", size=2 * 2**30),
+                                _StorageInstance(name="org1", size=2**30),
+                                _StorageInstance(name="org2", size=2 * 2**30),
                             ],
                         ),
                     ),
@@ -257,12 +257,11 @@ class TestClustersFormatter:
                         credentials={},
                         node_pools=[],
                         storage=_GoogleStorage(
-                            id="standard",
                             description="Filestore",
                             tier=_GoogleFilestoreTier.STANDARD,
                             instances=[
-                                _StorageInstance(),
-                                _StorageInstance(name="org"),
+                                _StorageInstance(name="org1"),
+                                _StorageInstance(name="org2"),
                             ],
                         ),
                     ),
@@ -371,7 +370,6 @@ class TestCloudProviderOptionsFormatter:
             type=_CloudProviderType.AWS,
             node_pools=[
                 _NodePoolOptions(
-                    id="m5_xlarge",
                     machine_type="m5.xlarge",
                     cpu=4,
                     available_cpu=3,
@@ -379,23 +377,15 @@ class TestCloudProviderOptionsFormatter:
                     available_memory=14 * 2**30,
                 ),
                 _NodePoolOptions(
-                    id="p2_xlarge",
                     machine_type="p2.xlarge",
                     cpu=4,
                     available_cpu=3,
                     memory=64 * 10**3,
                     available_memory=60 * 2**30,
-                    gpu=1,
-                    gpu_model="nvidia-tesla-k80",
+                    nvidia_gpu=1,
+                    nvidia_gpu_model="nvidia-tesla-k80",
                 ),
             ],
-            storages=[
-                _AWSStorageOptions(
-                    id="generalPurpose_bursting",
-                    performance_mode=_EFSPerformanceMode.GENERAL_PURPOSE,
-                    throughput_mode=_EFSThroughputMode.BURSTING,
-                )
-            ],
         )
         rich_cmp(formatter(options))
 
@@ -405,7 +395,6 @@ class TestCloudProviderOptionsFormatter:
             type=_CloudProviderType.GCP,
             node_pools=[
                 _NodePoolOptions(
-                    id="n1_highmem_4",
                     machine_type="n1-highmem-4",
                     cpu=4,
                     available_cpu=3,
@@ -413,24 +402,15 @@ class TestCloudProviderOptionsFormatter:
                     available_memory=14 * 2**30,
                 ),
                 _NodePoolOptions(
-                    id="n1_highmem_4",
                     machine_type="n1-highmem-4",
                     cpu=4,
                     available_cpu=3,
                     memory=64 * 10**3,
                     available_memory=60 * 2**30,
-                    gpu=1,
-                    gpu_model="nvidia-tesla-k80",
+                    nvidia_gpu=1,
+                    nvidia_gpu_model="nvidia-tesla-k80",
                 ),
             ],
-            storages=[
-                _GoogleStorageOptions(
-                    id="standard",
-                    tier=_GoogleFilestoreTier.STANDARD,
-                    min_capacity=1 * 2**40,
-                    max_capacity=60 * 2**40,
-                )
-            ],
         )
         rich_cmp(formatter(options))
 
@@ -440,7 +420,6 @@ class TestCloudProviderOptionsFormatter:
             type=_CloudProviderType.AZURE,
             node_pools=[
                 _NodePoolOptions(
-                    id="Standard_D4_v3",
                     machine_type="Standard_D4_v3",
                     cpu=4,
                     available_cpu=3,
@@ -448,24 +427,82 @@ class TestCloudProviderOptionsFormatter:
                     available_memory=14 * 2**30,
                 ),
                 _NodePoolOptions(
-                    id="Standard_NC6",
                     machine_type="Standard_NC6",
                     cpu=4,
                     available_cpu=3,
                     memory=64 * 10**3,
                     available_memory=60 * 2**30,
-                    gpu=1,
-                    gpu_model="nvidia-tesla-k80",
+                    nvidia_gpu=1,
+                    nvidia_gpu_model="nvidia-tesla-k80",
                 ),
             ],
-            storages=[
-                _AzureStorageOptions(
-                    id="standard",
-                    tier=_AzureStorageTier.STANDARD,
-                    replication_type=_AzureReplicationType.LRS,
-                    min_file_share_size=100 * 2**30,
-                    max_file_share_size=100 * 2**40,
-                )
-            ],
         )
         rich_cmp(formatter(options))
+
+
+class TestOrgUserFormatter:
+    def test_list_users_with_user_info(self, rich_cmp: RichCmp) -> None:
+        formatter = OrgUserFormatter()
+        users = [
+            _OrgUserWithInfo(
+                user_name="denis",
+                org_name="org",
+                role=_OrgUserRoleType("admin"),
+                balance=_Balance(),
+                user_info=_UserInfo(
+                    first_name="denis",
+                    last_name="admin",
+                    email="denis@domain.name",
+                    created_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
+                ),
+            ),
+            _OrgUserWithInfo(
+                user_name="andrew",
+                org_name="org",
+                role=_OrgUserRoleType("manager"),
+                balance=_Balance(credits=Decimal(100)),
+                user_info=_UserInfo(
+                    first_name="andrew",
+                    last_name=None,
+                    email="andrew@domain.name",
+                    created_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
+                ),
+            ),
+            _OrgUserWithInfo(
+                user_name="ivan",
+                org_name="org",
+                role=_OrgUserRoleType("user"),
+                balance=_Balance(),
+                user_info=_UserInfo(
+                    first_name=None,
+                    last_name="user",
+                    email="ivan@domain.name",
+                    created_at=isoparse("2017-03-04T12:28:59.759433+00:00"),
+                ),
+            ),
+            _OrgUserWithInfo(
+                user_name="alex",
+                org_name="org",
+                role=_OrgUserRoleType("user"),
+                balance=_Balance(credits=Decimal(100), spent_credits=Decimal(20)),
+                user_info=_UserInfo(
+                    first_name=None,
+                    last_name=None,
+                    email="alex@domain.name",
+                    created_at=None,
+                ),
+            ),
+            _OrgUserWithInfo(
+                user_name="alex",
+                org_name="org",
+                role=_OrgUserRoleType("user"),
+                balance=_Balance(credits=Decimal(100), spent_credits=Decimal(20)),
+                user_info=_UserInfo(
+                    first_name=None,
+                    last_name=None,
+                    email="alex@domain.name",
+                    created_at=None,
+                ),
+            ),
+        ]
+        rich_cmp(formatter(users))
